fnss.netconfig.nodeconfig.clear_stacks — FNSS 0.6.1 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.6.1 documentation »
- API Reference »
- Functions »

# fnss.netconfig.nodeconfig.clear_stacks

`clear_stacks`(topology)

  Remove all stacks from all nodes of the topology

  Parameters: | topology : Topology

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.6.1 documentation »
- API Reference »
- Functions »